function s = periodicBScurve(b,k,t)
%
% s = periodicBScurve(b,k,t)
%
% periodic B-spline curve with control points b of order k evaluated at t
% b(:,end) ~= b(:,1)
% k > 1
s = zeros(size(b,1),size(t,2));
n = size(b,2)-1;
for i = 1:n+k%+1-min(k-1,1)
  s = s+diag(b(:,mod(i-1,n+1)+1))*...
      repmat(periodicB(k,n,k,((n+1)*t-(i-k))/(n+1)),size(b,1),1);
end
%!demo
%! b = [0,0,1,1;0,1,1,0];
%! t = linspace(0,1,101);
%! k = 3;
%! s = periodicBScurve(b,k,t);
%! plot(b(1,:),b(2,:),'o',s(1,:),s(2,:))
%! legend('control points','periodic B-spline curve')
%! axis([-0.2,1.2,-0.2,1.2])
%! axis square